"""
SJI - Eine einfache Python-Bibliothek für Job-Initialisierung.
"""

__version__ = "0.2.1"

from .sji import SimpleJobInit, get_script_version

__all__ = ["SimpleJobInit", "get_script_version"]     
